/* Copyright (C) 2013-2016, The Regents of The University of Michigan.
All rights reserved.
This software was developed in the APRIL Robotics Lab under the
direction of Edwin Olson, ebolson@umich.edu. This software may be
available under alternative licensing terms; contact the address above.
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
The views and conclusions contained in the software and documentation are those
of the authors and should not be interpreted as representing official policies,
either expressed or implied, of the Regents of The University of Michigan.
*/

#include <stdlib.h>
#include "tag36h10.h"

static uint64_t codedata[2320] = {
   0x00000001a42f9469UL,
   0x000000021a48c08dUL,
   0x000000026dfdbc5dUL,
   0x00000002d19b78fbUL,
   0x000000031c5557dfUL,
   0x00000003f2b3d349UL,
   0x00000003e6d4a7a5UL,
   0x000000043d6dfb6dUL,
   0x00000005688d2affUL,
   0x000000054663b474UL,
   0x000000067fd759e4UL,
   0x000000073b196d82UL,
   0x00000007de71c630UL,
   0x00000008492722d4UL,
   0x0000000835407afaUL,
   0x0000000893a6fe16UL,
   0x000000095668d348UL,
   0x00000009c20e37a4UL,
   0x0000000a19bb676cUL,
   0x0000000ad1355c1bUL,
   0x0000000b2ab4ac53UL,
   0x0000000b14f27095UL,
   0x0000000bef6b014dUL,
   0x0000000c9ecbadc7UL,
   0x0000000e1996a6bdUL,
   0x0000000edc588fcbUL,
   0x0000000f26d9d7a1UL,
   0x0000000035e79c1aUL,
   0x00000001644f74a8UL,
   0x00000001bfda85e0UL,
   0x000000020573db2aUL,
   0x000000027614bfd6UL,
   0x00000002daf26b72UL,
   0x0000000332930a98UL,
   0x00000003176c5674UL,
   0x00000003892ad2d0UL,
   0x00000003fd4d26acUL,
   0x00000004b88a1fcaUL,
   0x0000000555b6b579UL,
   0x00000006103880d7UL,
   0x00000006045e58fbUL,
   0x00000006dedf28a3UL,
   0x000000072766f249UL,
   0x00000007e4a0c77fUL,
   0x0000000973ba8e61UL,
   0x0000000965fd5285UL,
   0x00000009d99bd6a9UL,
   0x0000000a221264e6UL,
   0x0000000a1455fccaUL,
   0x0000000a7cb3193eUL,
   0x0000000aead44d92UL,
   0x0000000ad50ac954UL,
   0x0000000b2f0bb19cUL,
   0x0000000cba043aa2UL,
   0x0000000d73d7f6b4UL,
   0x0000000d6d189310UL,
   0x0000000f41278885UL,
   0x00000001c45306afUL,
   0x0000000222b4420bUL,
   0x00000002d70ceeb1UL,
   0x0000000392cb439fUL,
   0x000000045d1179eeUL,
   0x000000057a79d05cUL,
   0x000000062bc91dd6UL,
   0x000000073ca773c0UL,
   0x00000008b3da6eb0UL,
   0x00000009c5a521c7UL,
   0x0000000a812a1881UL,
   0x0000000adeab4859UL,
   0x0000000b3402b213UL,
   0x0000000b9171667fUL,
   0x0000000f5ac6918cUL,
   0x00000000549b1cfcUL,
   0x00000000b2744a58UL,
   0x00000000ae12ceb4UL,
   0x00000002f8aaab94UL,
   0x000000038db1c43bUL,
   0x00000004be190989UL,
   0x000000051bef9565UL,
   0x0000000505a8d1c3UL,
   0x0000000575ce25bfUL,
   0x000000068ac14eb1UL,
   0x00000006fd1bca45UL,
   0x0000000854752994UL,
   0x00000009e96b442aUL,
   0x0000000afb308f74UL,
   0x0000000cd9c8ca44UL,
   0x0000000d23c9b28eUL,
   0x0000000d07277423UL,
   0x0000000e8b3a6959UL,
   0x0000000f44bc546fUL,
   0x000000010e4aa7f3UL,
   0x000000029971cc68UL,
   0x000000062d7b0b94UL,
   0x00000008c22aac77UL,
   0x00000008b46d70d3UL,
   0x0000000a43373b0dUL,
   0x0000000e2efd2c74UL,
   0x0000000f5f4587e6UL,
   0x000000001b82bfa0UL,
   0x00000000642bef7aUL,
   0x00000001e576f881UL,
   0x00000002a290cda7UL,
   0x00000003b1ae80b1UL,
   0x000000053b9317e3UL,
   0x00000005833ac709UL,
   0x00000005f25d3ff5UL,
   0x0000000648fcef3dUL,
   0x000000068d6350d6UL,
   0x00000008064a4da6UL,
   0x000000092b76e736UL,
   0x00000009157102b0UL,
   0x00000009eef0de60UL,
   0x0000000b098e9306UL,
   0x0000000b63e94718UL,
   0x0000000c1241e99bUL,
   0x0000000eab42b39fUL,
   0x0000000fca2a422dUL,
   0x0000000007f86a4bUL,
   0x0000000124962550UL,
   0x00000001fe977988UL,
   0x0000000300a8b4c4UL,
   0x000000076c2b21a1UL,
   0x0000000932f76619UL,
   0x00000009994e9b51UL,
   0x0000000a634fcb8bUL,
   0x0000000b6d92c074UL,
   0x0000000bcbf53858UL,
   0x0000000c0c3a0d7eUL,
   0x000000001c31a9c3UL,
   0x00000000d5a694d5UL,
   0x000000012f2fc41dUL,
   0x00000005a342598aUL,
   0x00000006466af138UL,
   0x000000081eb68f22UL,
   0x000000098e885eb6UL,
   0x0000000ab594f405UL,
   0x0000000b19f201a1UL,
   0x0000000d44832643UL,
   0x0000000fdc915802UL,
   0x00000000ee4f05dcUL,
   0x00000003043aa2a6UL,
   0x00000003765d7a9aUL,
   0x00000005468500abUL,
   0x000000059d38dc6bUL,
   0x000000060b5e288fUL,
   0x00000009539ba6dfUL,
   0x00000009a93219d2UL,
   0x0000000ad81ab160UL,
   0x0000000abe7d650cUL,
   0x0000000beb8dd89eUL,
   0x0000000bd5432e10UL,
   0x000000009aafb509UL,
   0x000000014f535a9bUL,
   0x0000000202956e9dUL,
   0x00000003d64508f8UL,
   0x00000005babe994eUL,
   0x00000006d1c1e752UL,
   0x000000094cb57d7bUL,
   0x00000009a45c8c11UL,
   0x0000000a7f4dd4c9UL,
   0x0000000d6ab9426bUL,
   0x0000000da6766828UL,
   0x0000000f1608f9bcUL,
   0x000000016ad49fb6UL,
   0x00000006da68e61fUL,
   0x00000006ce0e03bbUL,
   0x0000000a0404d752UL,
   0x0000000e066e102fUL,
   0x00000002f9d00546UL,
   0x000000039878a9e4UL,
   0x000000049521229cUL,
   0x00000008a70b85a9UL,
   0x000000096ecdad9dUL,
   0x00000009b5300ed7UL,
   0x0000000d08e19cd0UL,
   0x0000000e1dbbf0a6UL,
   0x0000000ef012435cUL,
   0x00000006ecd2fc10UL,
   0x0000000749a519f4UL,
   0x000000091b715e4cUL,
   0x000000090f17dae8UL,
   0x0000000975d0ae16UL,
   0x00000009ced1f6deUL,
   0x0000000ba3660c0bUL,
   0x0000000d1b1c9d9dUL,
   0x0000000d77fa492bUL,
   0x0000000de0bdcdc7UL,
   0x0000000e2472e389UL,
   0x000000039ee6b70eUL,
   0x00000007a8ad48b3UL,
   0x0000000b4ee1682eUL,
   0x0000000bb8a7ec82UL,
   0x000000007cd0404dUL,
   0x000000011d68ecc7UL,
   0x000000046cbd039dUL,
   0x00000004b634dd1aUL,
   0x000000063c6d44e0UL,
   0x0000000981a82ea0UL,
   0x0000000a93f25d5fUL,
   0x0000000a8795d9fbUL,
   0x0000000b5d3c69a3UL,
   0x0000000f56912854UL,
   0x00000001f86096b4UL,
   0x00000001ee865210UL,
   0x000000024bf5c67cUL,
   0x000000037a5d0beeUL,
   0x00000003c2fcd384UL,
   0x00000005324bc851UL,
   0x00000005886a7099UL,
   0x0000000b72fa2c2cUL,
   0x0000000fc92eb5b5UL,
   0x0000000422e4a0c6UL,
   0x000000059b17b310UL,
   0x00000008e7d2e941UL,
   0x0000000943f50c2dUL,
   0x000000093db38889UL,
   0x0000000d3c56115cUL,
   0x0000000ec3097940UL,
   0x0000000f0c8e4c64UL,
   0x000000015a1a2b44UL,
   0x000000031885e859UL,
   0x00000003c77ec56fUL,
   0x0000000665489b09UL,
   0x0000000ac8831e70UL,
   0x0000000b0559325eUL,
   0x0000000d9d4e401bUL,
   0x00000001618bca4bUL,
   0x00000006cd54c849UL,
   0x0000000717d5b003UL,
   0x0000000acb7e0f3dUL,
   0x0000000db2c90514UL,
   0x0000000edb75ab84UL,
   0x00000002d2d82857UL,
   0x000000095fb613c6UL,
   0x00000009c1f187c8UL,
   0x0000000b1521d0f9UL,
   0x0000000f252b178dUL,
   0x00000003fe0f8640UL,
   0x00000005ca93c171UL,
   0x00000009dad88605UL,
   0x0000000b32a795d4UL,
   0x0000000d0273d2e4UL,
   0x0000000d7034b6d8UL,
   0x000000021d211a8bUL,
   0x000000032f7b66d5UL,
   0x000000097f46e061UL,
   0x0000000a3a80d947UL,
   0x0000000af24f7511UL,
   0x000000017760c682UL,
   0x00000002f17d53f8UL,
   0x00000005768d8553UL,
   0x00000005ccac399bUL,
   0x0000000b363443b6UL,
   0x000000086e868835UL,
   0x0000000d1f31c586UL,
   0x0000000e3c1f8c18UL,
   0x0000000dfb29b8f1UL,
   0x000000012545997cUL,
   0x00000003c9b87c9cUL,
   0x0000000650afcedaUL,
   0x00000007cc5d2d4dUL,
   0x0000000e97f2c6b4UL,
   0x0000000bcf094d17UL,
   0x0000000c2b6fd1b3UL,
   0x000000055b7539e1UL,
   0x00000006563c3099UL,
   0x00000006cbcaa475UL,
   0x0000000711ebf8bfUL,
   0x0000000beacf0872UL,
   0x0000000152bf7dd3UL,
   0x00000002d9e666a9UL,
   0x00000008aadf624cUL,
   0x0000000ae04840c3UL,
   0x0000000b89fceccbUL,
   0x0000000391534881UL,
   0x00000006d3b626f3UL,
   0x0000000b8cd3f384UL,
   0x000000056e622ea0UL,
   0x000000072da9effcUL,
   0x00000009d9dc3195UL,
   0x00000009b5bab5bbUL,
   0x0000000a2255635fUL,
   0x0000000b3d6b2a41UL,
   0x0000000e1e78a0caUL,
   0x00000006f166d850UL,
   0x00000006ed013c3cUL,
   0x0000000974124e7aUL,
   0x0000000b9c237103UL,
   0x000000012a55c948UL,
   0x00000006e6e02db3UL,
   0x0000000bb970b4aeUL,
   0x0000000cb5e92956UL,
   0x000000024a8a8519UL,
   0x00000005e4e6a504UL,
   0x0000000cce402a5bUL,
   0x0000000ead45ac6bUL,
   0x0000000b7e065329UL,
   0x00000002c9b38934UL,
   0x0000000550a5f272UL,
   0x00000009af15026bUL,
   0x0000000c43acbba9UL,
   0x000000003c4f2ed0UL,
   0x00000005a6df5a79UL,
   0x0000000acf8a733eUL,
   0x0000000e05408ed3UL,
   0x000000060787293bUL,
   0x000000089e95533fUL,
   0x0000000dcb673abcUL,
   0x0000000e0ea10fdaUL,
   0x0000000efa4f932eUL,
   0x000000045e988b2bUL,
   0x00000005d2c11c5eUL,
   0x0000000b84be5c13UL,
   0x000000050629a003UL,
   0x00000005e11c1dd3UL,
   0x000000012111629fUL,
   0x00000002365f3381UL,
   0x00000004cf5d41c0UL,
   0x00000008d957e5b5UL,
   0x000000025b88ce2cUL,
   0x000000041ec563d3UL,
   0x0000000c3884919fUL,
   0x00000004ffd91f28UL,
   0x0000000d6211be2eUL,
   0x00000002c6c33e2bUL,
   0x00000009b062517dUL,
   0x00000009a605d5d1UL,
   0x0000000c93615ffbUL,
   0x00000000587aa508UL,
   0x0000000ae741eba5UL,
   0x00000004b232ba75UL,
   0x00000009d68187b1UL,
   0x0000000a253c3b79UL,
   0x0000000bae55c0a6UL,
   0x0000000d0eaa3172UL,
   0x0000000c0c2dbd49UL,
   0x0000000d1d37d23fUL,
   0x0000000e952ecf4fUL,
   0x0000000a51239d5eUL,
   0x0000000f6e416099UL,
   0x0000000da4923cf8UL,
   0x000000055cd5bbbfUL,
   0x000000067fad4a0dUL,
   0x00000006f802d5abUL,
   0x00000004c90df6abUL,
   0x0000000cc0aad0e1UL,
   0x0000000745207f2bUL,
   0x0000000b516ad892UL,
   0x00000008da9ca7d8UL,
   0x0000000ba7517799UL,
   0x0000000b13811fcdUL,
   0x00000000328436caUL,
   0x00000005965ad68fUL,
   0x0000000e6b65823fUL,
   0x0000000951a1abf3UL,
   0x000000095cce7616UL,
   0x0000000ca003fe57UL,
   0x0000000d5ee5d32bUL,
   0x00000002d6d58f8eUL,
   0x0000000bee25c778UL,
   0x000000021cac7ed2UL,
   0x00000007b982415fUL,
   0x0000000237a92d3eUL,
   0x000000065c2a898aUL,
   0x00000002a67c67d0UL,
   0x0000000492c37445UL,
   0x0000000e66713585UL,
   0x0000000adb041611UL,
   0x00000009b5ed4c88UL,
   0x0000000f2f751a83UL,
   0x000000005a5db231UL,
   0x00000008478d5037UL,
   0x00000005e2954c13UL,
   0x00000000d8597d1dUL,
   0x0000000537116e24UL,
   0x00000007ce063461UL,
   0x0000000a79a20302UL,
   0x0000000b8016f46aUL,
   0x0000000ebeb44bdcUL,
   0x0000000206e7cff7UL,
   0x00000000d2870a69UL,
   0x00000004e21e723aUL,
   0x00000006a59590e7UL,
   0x0000000a522a2e9bUL,
   0x0000000c2ec8f44fUL,
   0x000000003e51273cUL,
   0x000000056bab7c9bUL,
   0x0000000b3a92fa7eUL,
   0x0000000f4a993d4bUL,
   0x00000008b80884b7UL,
   0x00000008a5339f30UL,
   0x0000000690c7389dUL,
   0x00000009f34cb283UL,
   0x0000000cd0febc20UL,
   0x0000000f579a2a82UL,
   0x00000003ba18373fUL,
   0x000000068fddad38UL,
   0x00000007ca529286UL,
   0x0000000df93cd25bUL,
   0x00000007d18313a9UL,
   0x0000000febd825c0UL,
   0x0000000898d72da2UL,
   0x0000000c2d8c5adeUL,
   0x000000060b797eeaUL,
   0x00000007281731bdUL,
   0x0000000b48a4940aUL,
   0x0000000d7e28a20dUL,
   0x000000006d0aac8eUL,
   0x00000002f418d6e8UL,
   0x000000045ce7d55fUL,
   0x0000000bb3415aa6UL,
   0x0000000f592d643dUL,
   0x00000000c556e7e9UL,
   0x0000000dede56c4eUL,
   0x0000000075f63628UL,
   0x0000000778f69c5bUL,
   0x0000000b0add7ab7UL,
   0x0000000d86f0b737UL,
   0x00000006d3092589UL,
   0x0000000776618a1bUL,
   0x0000000ecec99b8cUL,
   0x000000038a56d5b3UL,
   0x0000000e0cb464d1UL,
   0x00000000b9385f3aUL,
   0x0000000ba42a64f5UL,
   0x0000000938bb73f3UL,
   0x0000000a7691cb01UL,
   0x000000086a986dadUL,
   0x0000000447ed963bUL,
   0x0000000b6bcab900UL,
   0x0000000a348c9079UL,
   0x000000071812b90bUL,
   0x0000000be867b1a9UL,
   0x00000007807672aeUL,
   0x0000000f52c97520UL,
   0x000000005f6dabb7UL,
   0x00000001321e1472UL,
   0x0000000e44ab0b16UL,
   0x000000031b1b920fUL,
   0x0000000e7a916c37UL,
   0x0000000ec3a095ddUL,
   0x0000000e1cc9b481UL,
   0x000000046209b37bUL,
   0x000000047f0aa439UL,
   0x00000000d7b31befUL,
   0x000000052db78a32UL,
   0x0000000ed3b35ea8UL,
   0x00000005b1f58572UL,
   0x0000000acf866c7dUL,
   0x0000000fa2be6544UL,
   0x0000000774737a28UL,
   0x0000000bcf8fe9b1UL,
   0x0000000fdfc4ac80UL,
   0x0000000a0aef3457UL,
   0x00000005d93f4f4aUL,
   0x0000000a314ac7faUL,
   0x0000000b52221849UL,
   0x0000000b5d908dacUL,
   0x0000000ec20c9ce2UL,
   0x0000000da5563b12UL,
   0x000000057257c59bUL,
   0x0000000ef0e8f782UL,
   0x0000000f9d2b3dc4UL,
   0x0000000ab8097620UL,
   0x0000000b99a08acaUL,
   0x0000000064fe5b8bUL,
   0x000000019255e746UL,
   0x0000000aab6d88b0UL,
   0x0000000e011adc1bUL,
   0x00000003214f657cUL,
   0x0000000093f917b4UL,
   0x000000091f0c7859UL,
   0x0000000bcd3a5171UL,
   0x00000000afd4cb29UL,
   0x00000008787d5924UL,
   0x000000024f3a8b55UL,
   0x00000002ae32d017UL,
   0x000000067af72a45UL,
   0x00000008fe87d42aUL,
   0x0000000902c5df3fUL,
   0x00000002f2500693UL,
   0x0000000868a4733cUL,
   0x00000005dd4c95d9UL,
   0x000000097210f5f2UL,
   0x000000023f0de89fUL,
   0x000000084ce8a4b5UL,
   0x000000034eb80e3dUL,
   0x0000000532c70decUL,
   0x000000013b90cb54UL,
   0x0000000c3dfe6cb7UL,
   0x00000008b03d0badUL,
   0x000000090bacd3e5UL,
   0x0000000afa0bc824UL,
   0x0000000a38fe08f8UL,
   0x0000000fa758ea36UL,
   0x0000000fe0862d3cUL,
   0x00000001ace4f7edUL,
   0x0000000e04bac135UL,
   0x000000063e99b95aUL,
   0x0000000b010d68e1UL,
   0x0000000ce9352b2bUL,
   0x000000082838db6fUL,
   0x0000000d3bf04d59UL,
   0x0000000c9df5aec3UL,
   0x0000000a4e8aafeeUL,
   0x00000006b1db1459UL,
   0x00000006ba3217d0UL,
   0x0000000e5c73549cUL,
   0x000000037c2679dfUL,
   0x0000000732d69874UL,
   0x000000073ce98c9eUL,
   0x00000004cc0f5c5eUL,
   0x000000008f1b8c73UL,
   0x0000000ef1b22865UL,
   0x000000006f5eb759UL,
   0x00000001476bea11UL,
   0x000000078ba48850UL,
   0x000000074ac468d5UL,
   0x00000008ed2a2869UL,
   0x0000000a0d4f4fcdUL,
   0x00000002401bcfacUL,
   0x0000000af4852356UL,
   0x0000000e49487115UL,
   0x0000000678ebe495UL,
   0x00000003afec50b5UL,
   0x0000000ff853144eUL,
   0x0000000ca35def53UL,
   0x000000087328bda4UL,
   0x0000000d258703b5UL,
   0x000000071152a781UL,
   0x00000004dd323e43UL,
   0x00000004812c5a59UL,
   0x000000057bd1d082UL,
   0x0000000456266e15UL,
   0x00000006b9fccad6UL,
   0x00000004abe3b07bUL,
   0x0000000baf59cfceUL,
   0x000000056d6932fcUL,
   0x0000000fd158446cUL,
   0x0000000363f31ca6UL,
   0x000000093c9eecceUL,
   0x000000033930d57fUL,
   0x000000062c9dcfbbUL,
   0x00000006f52475c4UL,
   0x0000000950d51d55UL,
   0x000000095c430b37UL,
   0x00000007424acdf9UL,
   0x00000005e59f504fUL,
   0x00000007abe9fe84UL,
   0x00000001462e4fb3UL,
   0x00000005b346387fUL,
   0x0000000adcf80432UL,
   0x0000000dbcf4c50eUL,
   0x0000000213274059UL,
   0x00000007d0da7a11UL,
   0x0000000d9c5de950UL,
   0x0000000334edcf91UL,
   0x0000000eaadbf8b8UL,
   0x00000004fd450926UL,
   0x00000009a8af56b0UL,
   0x000000028b062348UL,
   0x000000086bd1c31dUL,
   0x00000000d15dd6c2UL,
   0x00000008cc9d14c6UL,
   0x0000000d0b9038c4UL,
   0x0000000b445f90b9UL,
   0x0000000c3378c977UL,
   0x0000000197aa5976UL,
   0x0000000f5879d3e2UL,
   0x00000002ec330e97UL,
   0x00000004bcab4ba7UL,
   0x0000000185b91b99UL,
   0x00000009a64ecebfUL,
   0x0000000e8b66c585UL,
   0x00000005e1e848ecUL,
   0x0000000a24ca255bUL,
   0x00000006a0d7dfc7UL,
   0x0000000770e1711aUL,
   0x00000007e34402b4UL,
   0x0000000525ceff8cUL,
   0x000000089a56e0c9UL,
   0x0000000ee1401ffcUL,
   0x0000000b13cfa633UL,
   0x0000000327aa9b9aUL,
   0x000000077383d86dUL,
   0x0000000eb6d7283eUL,
   0x00000004ba294b54UL,
   0x000000026c84d5d9UL,
   0x00000001c2c5adc0UL,
   0x0000000694e6ec3cUL,
   0x00000000f3064d10UL,
   0x00000006b7c9d416UL,
   0x0000000d7d74bd89UL,
   0x0000000e11232372UL,
   0x00000004d84369e0UL,
   0x0000000f7de40249UL,
   0x0000000b64950611UL,
   0x0000000a0724a19bUL,
   0x0000000688eef9abUL,
   0x00000003c7a3a2eaUL,
   0x000000049cd79585UL,
   0x00000006c35bff78UL,
   0x0000000456a31970UL,
   0x00000004205eb8ecUL,
   0x00000002717c22e3UL,
   0x0000000763d127fbUL,
   0x0000000865548e6fUL,
   0x00000004f1dcc597UL,
   0x0000000279dcfca4UL,
   0x0000000aad1f2e05UL,
   0x00000006437570c6UL,
   0x0000000d68b74cd9UL,
   0x0000000ec82e7216UL,
   0x00000004223b2229UL,
   0x00000009c12a8582UL,
   0x0000000c073eb63dUL,
   0x000000068b779e29UL,
   0x000000061157ce5fUL,
   0x000000050f6ebec2UL,
   0x000000035f4e4b1cUL,
   0x0000000f909c56d6UL,
   0x00000009c4b78474UL,
   0x0000000b8160eb1eUL,
   0x00000005e3d256f8UL,
   0x000000021919b529UL,
   0x0000000d4c7b6226UL,
   0x00000005190049a8UL,
   0x0000000ad869eab6UL,
   0x0000000a10b3759aUL,
   0x0000000917560e43UL,
   0x00000002c5d651d7UL,
   0x0000000eb2c8e47cUL,
   0x0000000bc131902dUL,
   0x00000007e883469bUL,
   0x000000091d991bfeUL,
   0x000000020c3a7704UL,
   0x00000002b3b53f8fUL,
   0x00000008978b2c6aUL,
   0x000000091138b228UL,
   0x0000000529f08e2cUL,
   0x0000000979342793UL,
   0x000000098137dcc3UL,
   0x00000003a9c6e139UL,
   0x0000000f898abd5eUL,
   0x0000000ce2585f36UL,
   0x0000000968312f45UL,
   0x00000002994a6ec2UL,
   0x0000000ca6685871UL,
   0x0000000a3af94337UL,
   0x000000003f628d34UL,
   0x00000001e9617f6cUL,
   0x0000000a34ed1a9cUL,
   0x00000002c22028b4UL,
   0x0000000fdeb13f3aUL,
   0x000000002d85e3acUL,
   0x0000000957491696UL,
   0x0000000ac42bab89UL,
   0x0000000e3753d50fUL,
   0x0000000b712a307aUL,
   0x00000008b7c1c2caUL,
   0x00000008893cb8f8UL,
   0x00000005abc4467fUL,
   0x00000005f1aa96c0UL,
   0x0000000b7dcde504UL,
   0x0000000c3cd9ca20UL,
   0x00000000af48c055UL,
   0x0000000f4e10477bUL,
   0x000000012b45078cUL,
   0x000000010af764c6UL,
   0x000000023d8b32d5UL,
   0x000000036f1e9c47UL,
   0x0000000e847bd756UL,
   0x00000004c3b4e455UL,
   0x000000064d42e688UL,
   0x0000000cf5218b7aUL,
   0x0000000cdc1605e4UL,
   0x00000006250bba26UL,
   0x0000000be6c4770aUL,
   0x0000000982331a23UL,
   0x0000000dfd090dcaUL,
   0x0000000506bc18d5UL,
   0x0000000109d7375cUL,
   0x0000000680ca4a7eUL,
   0x0000000a6e1c91e1UL,
   0x0000000688f44350UL,
   0x0000000ad470ae05UL,
   0x0000000f3ff0a79eUL,
   0x0000000326f26fbeUL,
   0x00000004105901beUL,
   0x000000032ed82cd9UL,
   0x000000009916c638UL,
   0x00000001d0025ed6UL,
   0x00000004aeaec114UL,
   0x000000098af27931UL,
   0x0000000968f79b3bUL,
   0x0000000ed4b906d5UL,
   0x000000061ae9b2e4UL,
   0x000000059b82a3f5UL,
   0x0000000550eb833bUL,
   0x000000017b69fd4bUL,
   0x000000073d569e02UL,
   0x000000063dba43f8UL,
   0x0000000f6cb4cb8aUL,
   0x0000000d6258181bUL,
   0x0000000e86109784UL,
   0x0000000fa5a660eaUL,
   0x00000004f9815064UL,
   0x000000075d8db35dUL,
   0x0000000546f94888UL,
   0x000000058df2d00aUL,
   0x00000006a779d19bUL,
   0x0000000ea1b4e76bUL,
   0x000000014870eef0UL,
   0x000000055429f855UL,
   0x0000000e86b71b9fUL,
   0x0000000d333c2d43UL,
   0x000000042733ecd4UL,
   0x0000000d16ba12efUL,
   0x00000003b69c3d5cUL,
   0x00000004a5c07666UL,
   0x0000000a84634048UL,
   0x000000021a2c4b26UL,
   0x0000000573be1892UL,
   0x0000000730bd1d40UL,
   0x0000000eed055d81UL,
   0x00000007e815e7a6UL,
   0x00000008ab11c883UL,
   0x000000050283e7d2UL,
   0x0000000c8a795b85UL,
   0x000000047a229dc5UL,
   0x000000012b9e108cUL,
   0x0000000caa2034dbUL,
   0x0000000a62f9ae47UL,
   0x000000093979dcfaUL,
   0x00000005fb8fd985UL,
   0x000000025bf32ccbUL,
   0x00000007ae9a5ee5UL,
   0x0000000b10665d2eUL,
   0x0000000ed0c2b0e6UL,
   0x00000002c72c25fdUL,
   0x0000000d74f444d2UL,
   0x00000009b0db80cbUL,
   0x000000055c8e43deUL,
   0x0000000d77253912UL,
   0x000000084cfd9ea0UL,
   0x00000001615ba8c5UL,
   0x0000000503884d62UL,
   0x0000000fc53328a8UL,
   0x0000000f547a6153UL,
   0x0000000ca97160cfUL,
   0x000000095e440434UL,
   0x00000006fa4c125dUL,
   0x0000000a420cfe45UL,
   0x0000000af8147dfbUL,
   0x000000012e90ddeaUL,
   0x0000000f14c3cb5eUL,
   0x0000000966579d6aUL,
   0x00000004447c94d0UL,
   0x000000032336aceaUL,
   0x0000000c75d077dfUL,
   0x0000000b7e72837eUL,
   0x000000051d24ed1eUL,
   0x000000093fb67f5cUL,
   0x000000085cedc1b2UL,
   0x00000003ca6c5d2bUL,
   0x000000032269be93UL,
   0x0000000120ed410cUL,
   0x0000000fe115d3d4UL,
   0x00000000a045ed79UL,
   0x000000083e2846deUL,
   0x00000004e7a34f3bUL,
   0x00000005078cae37UL,
   0x0000000c831aa1f0UL,
   0x000000079de6b9b6UL,
   0x00000008e39b1ad2UL,
   0x000000066bdb37a5UL,
   0x00000004a79f5da7UL,
   0x0000000cd9693b30UL,
   0x00000000dc69a07aUL,
   0x00000008649a002fUL,
   0x0000000932887d37UL,
   0x00000003926b6a74UL,
   0x0000000c5d4f8ff8UL,
   0x0000000ea290f911UL,
   0x0000000360e344e9UL,
   0x00000007fa9e8a19UL,
   0x0000000b1d0c16c3UL,
   0x00000001bbe55ddcUL,
   0x0000000825cdaea9UL,
   0x000000004f67f00fUL,
   0x0000000d3df43a25UL,
   0x0000000b07b349a2UL,
   0x0000000716a39611UL,
   0x0000000aa0fc66b7UL,
   0x0000000f928fca14UL,
   0x0000000697c299d3UL,
   0x00000006dea5d945UL,
   0x000000038cee4ea7UL,
   0x00000004e67ea7b6UL,
   0x000000024deb4062UL,
   0x0000000e4428a670UL,
   0x00000008fdb1ad13UL,
   0x0000000318ff0e1cUL,
   0x000000008c148b5dUL,
   0x0000000dbf90b839UL,
   0x000000003ea5b027UL,
   0x000000042b077ba9UL,
   0x0000000b528450e0UL,
   0x0000000a1256cbfdUL,
   0x00000004798a8e57UL,
   0x00000001fdc0d38fUL,
   0x0000000146329edcUL,
   0x0000000fa0f94b03UL,
   0x000000056c6f0e19UL,
   0x000000006db661a7UL,
   0x0000000681addf27UL,
   0x00000000d1eded30UL,
   0x0000000765c3d6e7UL,
   0x00000001ba6ae5adUL,
   0x00000005e0b49af4UL,
   0x000000033176fa1cUL,
   0x000000064ca46a3aUL,
   0x0000000389363b6fUL,
   0x00000008cc072db9UL,
   0x0000000b25f03d8fUL,
   0x000000056aa81ab1UL,
   0x00000002b1c37b54UL,
   0x0000000ac1c3279dUL,
   0x0000000669af74edUL,
   0x000000064816db93UL,
   0x0000000254f44a17UL,
   0x0000000c1f5fc290UL,
   0x0000000ebca3a222UL,
   0x000000020e75e68bUL,
   0x0000000d3bb4dfc2UL,
   0x00000008d9167a74UL,
   0x0000000b6de37939UL,
   0x0000000f7a9a93d6UL,
   0x00000009aab08164UL,
   0x00000006d186ddfcUL,
   0x000000004d3e529cUL,
   0x0000000a53e2a5c4UL,
   0x0000000d5e40b964UL,
   0x00000009a1d76463UL,
   0x00000007ad6a8eccUL,
   0x000000030b0c9279UL,
   0x0000000351e5b489UL,
   0x0000000bba967fe0UL,
   0x0000000ab3d8bf17UL,
   0x000000016c42b17aUL,
   0x00000009744fae63UL,
   0x000000077a3f2d39UL,
   0x000000083c0190acUL,
   0x00000008d016cba0UL,
   0x00000005eb9f1e35UL,
   0x00000006349c2c93UL,
   0x0000000f5a15e641UL,
   0x00000007a5bc8c86UL,
   0x000000065b6b9834UL,
   0x0000000b756618a7UL,
   0x0000000d297dc208UL,
   0x00000003d6cfca2aUL,
   0x0000000c26e4a930UL,
   0x00000003afd2df57UL,
   0x00000007f990decdUL,
   0x00000006665a2f43UL,
   0x0000000345d16f4fUL,
   0x0000000322e392bdUL,
   0x0000000567baa5deUL,
   0x00000004a6412121UL,
   0x0000000a102338a6UL,
   0x0000000b130fd768UL,
   0x000000072a30a317UL,
   0x0000000e4b71cd71UL,
   0x0000000ad4b2ceebUL,
   0x00000001da4e11cfUL,
   0x0000000d5df39b45UL,
   0x000000081622faa8UL,
   0x000000098f38af5cUL,
   0x000000025397c292UL,
   0x00000002cfcdb0d7UL,
   0x0000000d24542679UL,
   0x000000004f04f5f4UL,
   0x0000000254842f2cUL,
   0x0000000c6fce4a81UL,
   0x00000001518648bfUL,
   0x000000029ead8e85UL,
   0x0000000dc1435a6bUL,
   0x0000000c8ebc91afUL,
   0x0000000bcc94c093UL,
   0x00000008285d6a81UL,
   0x00000005b5cca263UL,
   0x000000005279a4fdUL,
   0x00000008c7dc69a7UL,
   0x0000000963e0b3fcUL,
   0x0000000e38519cb6UL,
   0x0000000e84af68a5UL,
   0x0000000d20ee188dUL,
   0x000000074fdc8660UL,
   0x000000056f95f633UL,
   0x0000000f5d2233bfUL,
   0x0000000ecb3c9815UL,
   0x0000000c21a3cee6UL,
   0x00000001558f2f83UL,
   0x00000008ea10ea50UL,
   0x00000007ededa109UL,
   0x00000004d4c5e25dUL,
   0x0000000130e15fa7UL,
   0x000000064c873cc7UL,
   0x000000035a0225a3UL,
   0x0000000d37aefb27UL,
   0x0000000b441d8903UL,
   0x00000002339f650bUL,
   0x0000000c52d79fa9UL,
   0x0000000a28badc40UL,
   0x0000000e2b99967cUL,
   0x00000008726656b3UL,
   0x0000000124e07029UL,
   0x00000008582b1dabUL,
   0x00000004eb90cbeeUL,
   0x0000000bff16b8acUL,
   0x0000000a408251fdUL,
   0x00000004feccced5UL,
   0x0000000edda7bf1cUL,
   0x000000055a0d37b2UL,
   0x00000000dd9dc90eUL,
   0x0000000a537c9ad8UL,
   0x00000008b007aeb4UL,
   0x00000006e17fbab4UL,
   0x00000000d03559e3UL,
   0x000000066fb4aaacUL,
   0x0000000d06449a6bUL,
   0x0000000528bb1818UL,
   0x000000048f0d8baeUL,
   0x0000000834d540b7UL,
   0x000000023d5d9ab9UL,
   0x00000001a13b04d1UL,
   0x0000000bd30cc9afUL,
   0x0000000e392c0fb4UL,
   0x0000000fd5d4e8bdUL,
   0x0000000cbc646d45UL,
   0x0000000348db96b7UL,
   0x0000000e32e54c5fUL,
   0x000000062446b63fUL,
   0x0000000ea47a2c4dUL,
   0x00000008d4d99969UL,
   0x0000000d01d6d0d2UL,
   0x00000001862cef24UL,
   0x0000000ed64fe4baUL,
   0x0000000d48b40fecUL,
   0x000000030aa27a14UL,
   0x00000008b2fcfdceUL,
   0x0000000943824f9aUL,
   0x0000000bab9f8d09UL,
   0x00000003204c129fUL,
   0x0000000823a36283UL,
   0x00000005a0b07693UL,
   0x0000000437949450UL,
   0x00000004ad8ca4c5UL,
   0x0000000ec979f418UL,
   0x0000000e4ed18627UL,
   0x00000008cd5d978dUL,
   0x00000005b33248f0UL,
   0x0000000bf5ac9f64UL,
   0x0000000bd427f795UL,
   0x0000000d19d39539UL,
   0x00000009f4a46c35UL,
   0x0000000532019548UL,
   0x0000000b0ebce22cUL,
   0x0000000b91133fbcUL,
   0x00000006f1983636UL,
   0x00000008f898fed7UL,
   0x0000000e642bf2ccUL,
   0x0000000a8841dfe9UL,
   0x0000000c6b879b48UL,
   0x00000007ad82cc2eUL,
   0x0000000651977fc1UL,
   0x00000004dcf4f025UL,
   0x0000000c94950e6cUL,
   0x00000002595c6eddUL,
   0x0000000d4490ebe6UL,
   0x00000004105ad270UL,
   0x0000000903d8c8efUL,
   0x000000062531ad0bUL,
   0x00000001c1fd55b3UL,
   0x0000000d27d4ced8UL,
   0x0000000dc62f305bUL,
   0x00000001e2557e49UL,
   0x0000000495c28cedUL,
   0x00000009c279d9dbUL,
   0x000000052aa6cef5UL,
   0x00000007ea533ab1UL,
   0x0000000d7d49e37bUL,
   0x0000000e8c5c7424UL,
   0x00000008137f4da1UL,
   0x0000000ae13670b3UL,
   0x00000000de97bd57UL,
   0x00000000759a6643UL,
   0x0000000d646248dfUL,
   0x0000000f5f13b6a3UL,
   0x0000000d12b2ecadUL,
   0x0000000205cccbb8UL,
   0x0000000fe6a5b5f2UL,
   0x0000000d1995e567UL,
   0x000000091d0f2174UL,
   0x0000000360e9ebefUL,
   0x0000000d304c9653UL,
   0x00000007eb43d360UL,
   0x00000009b24edb22UL,
   0x00000005aeb87d49UL,
   0x000000073a745811UL,
   0x0000000e1fd08936UL,
   0x000000033eeb68a9UL,
   0x00000006367edc20UL,
   0x000000036fd414d2UL,
   0x00000002e6722e78UL,
   0x00000006c7a9c15eUL,
   0x00000002330d46f7UL,
   0x0000000b6bc7a6e8UL,
   0x000000043eb954aaUL,
   0x000000005eadcf50UL,
   0x000000063e43b4eaUL,
   0x00000000351ca1f1UL,
   0x00000008b5682648UL,
   0x0000000c28f03f9aUL,
   0x0000000636bfe005UL,
   0x00000004ca1054e5UL,
   0x0000000440ed66c9UL,
   0x00000006e60f6fbcUL,
   0x00000006d94e25eeUL,
   0x0000000adfe9ec25UL,
   0x0000000f0cb53616UL,
   0x0000000cb19d69aaUL,
   0x0000000ff898685eUL,
   0x000000066ea208d6UL,
   0x00000005dadebaf0UL,
   0x0000000f3f7afea5UL,
   0x0000000a96739522UL,
   0x000000039a0ef88eUL,
   0x0000000626acbb6eUL,
   0x0000000ce0e42f8dUL,
   0x0000000883ae2d8fUL,
   0x0000000619bd4ce7UL,
   0x0000000be466b665UL,
   0x000000079e154eaeUL,
   0x000000073e2a0a7aUL,
   0x00000005ec94e92cUL,
   0x0000000898bc6465UL,
   0x0000000abce956ebUL,
   0x00000002b21e8995UL,
   0x000000086364e87dUL,
   0x0000000d58212c13UL,
   0x00000008b8c39e93UL,
   0x00000000a1546c8bUL,
   0x00000008abbe32b5UL,
   0x0000000e8a4a2512UL,
   0x0000000ad5ee178bUL,
   0x000000069cc1e886UL,
   0x00000005bc2f8d35UL,
   0x00000001bbcd0982UL,
   0x00000001fd969b1aUL,
   0x0000000ae9e4251bUL,
   0x00000009afc001adUL,
   0x000000069e9d82f9UL,
   0x000000092f852ed7UL,
   0x0000000adb6d7fe1UL,
   0x000000067b91999dUL,
   0x0000000fa2600b99UL,
   0x0000000d6735277eUL,
   0x0000000f836268edUL,
   0x0000000b7911c708UL,
   0x000000013427930eUL,
   0x0000000f24a44da1UL,
   0x0000000ed2f760e0UL,
   0x0000000920508584UL,
   0x00000009f1b07e2bUL,
   0x000000032c15b482UL,
   0x0000000ffcd64b43UL,
   0x0000000a055b6498UL,
   0x0000000b2a107a8bUL,
   0x0000000191147253UL,
   0x00000009c214bb01UL,
   0x00000008bb616abdUL,
   0x00000001ef7dea4aUL,
   0x00000009dd6d225dUL,
   0x000000095563112cUL,
   0x000000001e4d0569UL,
   0x0000000f21a51b18UL,
   0x0000000686d2a5ebUL,
   0x000000032032674aUL,
   0x0000000c3d902590UL,
   0x0000000856c92019UL,
   0x000000058ebdcd91UL,
   0x0000000df2c7f9aeUL,
   0x000000089d852225UL,
   0x0000000862c4110dUL,
   0x0000000dc7df8185UL,
   0x0000000c16e1da36UL,
   0x00000005a6749140UL,
   0x00000000e94d9865UL,
   0x000000032ec4b2feUL,
   0x0000000c80777c94UL,
   0x00000006869a7d57UL,
   0x00000008de18dc8eUL,
   0x0000000c98cc7379UL,
   0x000000079a6fa3a2UL,
   0x00000008b854287dUL,
   0x000000055bcd493bUL,
   0x0000000f3ddb56ecUL,
   0x0000000d15ec6405UL,
   0x0000000316f82362UL,
   0x000000039676e2a1UL,
   0x00000004044e831aUL,
   0x00000008444cf83bUL,
   0x000000064658814cUL,
   0x0000000d7ad48a68UL,
   0x0000000d5eb72583UL,
   0x0000000e11057b5dUL,
   0x0000000b7e3cd622UL,
   0x0000000a6a2f9c78UL,
   0x0000000a5924afe8UL,
   0x000000040a92e9baUL,
   0x0000000367a3950fUL,
   0x00000008dee1ebe9UL,
   0x000000052b717d05UL,
   0x00000009a5691e7dUL,
   0x0000000d454d2e0fUL,
   0x0000000fd8b299e9UL,
   0x0000000b2b1b84c2UL,
   0x00000004eacf400bUL,
   0x000000081eb4687eUL,
   0x00000005cd851fa7UL,
   0x00000001c285ea35UL,
   0x00000008ac9fdc95UL,
   0x00000001b612a6c3UL,
   0x000000094f92a63aUL,
   0x00000007debaf7c8UL,
   0x00000008cbcb7d94UL,
   0x0000000e439689eaUL,
   0x00000000932e63d2UL,
   0x0000000f3f641704UL,
   0x00000001acb5259eUL,
   0x0000000321ea6e39UL,
   0x000000061c65c02fUL,
   0x00000004282e42f2UL,
   0x00000001dd4ff338UL,
   0x0000000d91e27631UL,
   0x0000000d93927fceUL,
   0x00000004d40d6ae7UL,
   0x00000005bbfd1359UL,
   0x000000088bd393feUL,
   0x00000002535b3fd7UL,
   0x0000000b705488d3UL,
   0x00000009aa688843UL,
   0x00000009fa55ccf0UL,
   0x000000002cf10ca5UL,
   0x00000008235e2861UL,
   0x00000002610f1f02UL,
   0x0000000b203fbac1UL,
   0x0000000e05f02f3cUL,
   0x0000000b0d0e50adUL,
   0x0000000244eee955UL,
   0x00000004c5beb90dUL,
   0x000000013343b3c4UL,
   0x000000021bf9a392UL,
   0x0000000be95ecb69UL,
   0x0000000bc65857e2UL,
   0x00000008185173f4UL,
   0x0000000c3f6d059dUL,
   0x000000035c94e74aUL,
   0x0000000f72a083a3UL,
   0x00000005b36eab8fUL,
   0x0000000aa28606bbUL,
   0x0000000447d407bdUL,
   0x0000000d47eafc61UL,
   0x00000004e4dd872fUL,
   0x0000000abd276950UL,
   0x0000000b999bc572UL,
   0x00000008e0c5cee3UL,
   0x00000009fd2442d0UL,
   0x0000000bcb568051UL,
   0x0000000b87a1635bUL,
   0x0000000b3557c1e5UL,
   0x0000000ce9b07f46UL,
   0x00000000b6dfcfd2UL,
   0x000000028a540e7bUL,
   0x0000000bb04666c4UL,
   0x0000000b7baf38c6UL,
   0x0000000c37168124UL,
   0x0000000ca3c9589dUL,
   0x00000003529b99c0UL,
   0x0000000e8afab685UL,
   0x0000000bdc566027UL,
   0x00000003f1ded61bUL,
   0x0000000ce9930acdUL,
   0x000000008aa447dbUL,
   0x000000077a696e73UL,
   0x00000000eb44d17bUL,
   0x0000000c5d9c164dUL,
   0x00000001f98d7237UL,
   0x000000056a327041UL,
   0x0000000e9ecd1e58UL,
   0x00000000c2e0c7f4UL,
   0x0000000abf4a1a5eUL,
   0x00000009395c523eUL,
   0x0000000d014134faUL,
   0x00000005fbd62cadUL,
   0x0000000b247b4af6UL,
   0x0000000413f6fb3bUL,
   0x000000061c6ea7c4UL,
   0x00000008015ac6a5UL,
   0x00000000baf0e3ddUL,
   0x0000000ba1215e4aUL,
   0x0000000b01a9b92eUL,
   0x0000000c1516251fUL,
   0x000000001d0eeda9UL,
   0x0000000cf17f566fUL,
   0x00000003203947b3UL,
   0x00000007c92be543UL,
   0x0000000c320f34b8UL,
   0x00000006b1ff7e93UL,
   0x000000029d39ef02UL,
   0x0000000eda7b1139UL,
   0x0000000cca47d853UL,
   0x00000007ad24144dUL,
   0x00000007b082f234UL,
   0x0000000a6ec32320UL,
   0x0000000cf89eda25UL,
   0x0000000b64064998UL,
   0x0000000fa2314616UL,
   0x0000000d21789ac2UL,
   0x0000000d3c8d0f5dUL,
   0x00000006bac87d8dUL,
   0x00000001ff1311bdUL,
   0x00000002a1584b86UL,
   0x0000000b23dc8745UL,
   0x0000000eda5fcd76UL,
   0x0000000a7a9261d0UL,
   0x0000000512745cf6UL,
   0x00000002fc13fa8bUL,
   0x0000000e733958d3UL,
   0x0000000a057fc27dUL,
   0x0000000b4ffd8bbcUL,
   0x00000002abff4fb6UL,
   0x00000001d148a214UL,
   0x0000000d3c3c41fbUL,
   0x00000000cf542a81UL,
   0x0000000ee518b8dbUL,
   0x00000005d97028faUL,
   0x00000000dd153679UL,
   0x0000000d8e1610b5UL,
   0x0000000575122babUL,
   0x0000000090fec0a7UL,
   0x00000005aa2ee7deUL,
   0x0000000116ae8273UL,
   0x000000016991092eUL,
   0x00000003ab370aa5UL,
   0x00000003f0c514e6UL,
   0x0000000340ce20adUL,
   0x0000000d1cbbebb8UL,
   0x0000000aff5b363dUL,
   0x00000002f31fb255UL,
   0x00000005b7e53a8aUL,
   0x000000058d91de7cUL,
   0x00000006fdf2521fUL,
   0x000000080d755cb9UL,
   0x0000000cf8c9903bUL,
   0x00000000ab7ef0c7UL,
   0x00000003c61bf489UL,
   0x0000000fbfd14815UL,
   0x0000000baa647e90UL,
   0x0000000daf22defeUL,
   0x00000001a54cfe57UL,
   0x000000054d061818UL,
   0x0000000158deb36dUL,
   0x0000000a7955893aUL,
   0x0000000409b1960bUL,
   0x000000021cfed67eUL,
   0x0000000b478f7f56UL,
   0x00000002ff42f95dUL,
   0x000000048a06d3ecUL,
   0x0000000170957703UL,
   0x00000003925ece98UL,
   0x0000000d929cec5bUL,
   0x0000000aa5813ee5UL,
   0x00000009fb913a1eUL,
   0x0000000465854b47UL,
   0x00000008ac8a7343UL,
   0x000000084451853bUL,
   0x000000049987e033UL,
   0x000000075cd03c35UL,
   0x0000000cf326e2c1UL,
   0x0000000ed14fdb95UL,
   0x000000031a390e60UL,
   0x0000000a1959d956UL,
   0x00000001985d18b3UL,
   0x00000000b6b8bb85UL,
   0x0000000dc3fa4c95UL,
   0x00000003645fcf45UL,
   0x00000006c2146e60UL,
   0x00000008bdeaf7d6UL,
   0x00000005d0d268cfUL,
   0x00000008df1d5b62UL,
   0x000000077506eed4UL,
   0x00000005bebc26a3UL,
   0x0000000c78584caaUL,
   0x00000007ee6685bdUL,
   0x00000000d8af0a56UL,
   0x0000000e3a0db991UL,
   0x0000000625de434dUL,
   0x0000000582318bceUL,
   0x00000003ebe2bc3cUL,
   0x0000000ebd301053UL,
   0x00000005f579e6d7UL,
   0x0000000e9810d2aeUL,
   0x0000000b893145b4UL,
   0x0000000a7e7836d1UL,
   0x0000000679dac13bUL,
   0x00000008d99e4704UL,
   0x00000001c7234de5UL,
   0x0000000f23b8b6dbUL,
   0x0000000de8a6f02fUL,
   0x0000000bd2026bf8UL,
   0x0000000bb3903264UL,
   0x0000000ede8048afUL,
   0x000000060161ef64UL,
   0x00000008fc791a5bUL,
   0x00000006a4546243UL,
   0x0000000bc8187b47UL,
   0x0000000ff2ca8dcaUL,
   0x00000006bf71b837UL,
   0x000000078b8d1fe8UL,
   0x0000000e738cdd2aUL,
   0x00000007aa80d490UL,
   0x0000000fd1026293UL,
   0x0000000c96fe6ad3UL,
   0x000000083f0f4f7bUL,
   0x000000075cb39786UL,
   0x0000000b6ef13bddUL,
   0x0000000f6a89f8a5UL,
   0x000000099a14349eUL,
   0x00000001ce6c16e5UL,
   0x0000000a7597498fUL,
   0x0000000145206424UL,
   0x0000000013c9c5b3UL,
   0x0000000d25775fc6UL,
   0x000000072311ca63UL,
   0x0000000936d4cfe7UL,
   0x00000009ce43a505UL,
   0x0000000663594c01UL,
   0x000000042d1be7b6UL,
   0x000000080b1dc92dUL,
   0x000000020e8e5b75UL,
   0x00000000c2337a9eUL,
   0x000000058ae29f6bUL,
   0x000000090c553143UL,
   0x00000005b06da028UL,
   0x00000009415b2520UL,
   0x00000005dabcde8bUL,
   0x0000000d3c804332UL,
   0x0000000028d103dbUL,
   0x00000007be4cf210UL,
   0x000000056f76dd52UL,
   0x00000003877e1a3bUL,
   0x00000001f93eb430UL,
   0x00000000588972acUL,
   0x0000000c76cd7eb1UL,
   0x0000000852596e61UL,
   0x00000006fa0ead03UL,
   0x0000000d78be2bb6UL,
   0x000000056fdd6fd1UL,
   0x0000000e265b0ebdUL,
   0x0000000cc715a846UL,
   0x0000000ffb1e87a8UL,
   0x0000000d9893a834UL,
   0x0000000054c56923UL,
   0x000000063bbaac88UL,
   0x000000076a5585d4UL,
   0x0000000607b37e59UL,
   0x0000000ee4d4018bUL,
   0x00000007ef2d8dc5UL,
   0x0000000c1c2d4285UL,
   0x00000001e0be0a7bUL,
   0x00000009fbdac67eUL,
   0x0000000dc5c74ca1UL,
   0x00000008366e2f1cUL,
   0x0000000abf1e4843UL,
   0x00000007b55f4dacUL,
   0x00000003d6150197UL,
   0x00000004e034c8dbUL,
   0x000000063df500dfUL,
   0x000000034b89afd5UL,
   0x00000000a5ddabc7UL,
   0x00000009ee6ff8ecUL,
   0x00000003cdd9a682UL,
   0x0000000a8d46f842UL,
   0x00000005fec25f7dUL,
   0x00000004216835cfUL,
   0x00000001624430f9UL,
   0x000000018afb5b6cUL,
   0x00000009ffd34c8eUL,
   0x000000095d5882edUL,
   0x00000002e28d07cfUL,
   0x0000000fd9163bc2UL,
   0x0000000a5d0833d8UL,
   0x00000003ebaf5bfdUL,
   0x000000089a7a3e54UL,
   0x000000085d3f7dd8UL,
   0x00000008af8d1ba1UL,
   0x0000000a5b4e01b7UL,
   0x00000009f1accb0aUL,
   0x00000002fe5fcb31UL,
   0x00000002c4484bedUL,
   0x0000000a124de2eeUL,
   0x000000051471f700UL,
   0x000000014f7195f8UL,
   0x00000003ab7e9700UL,
   0x00000004542a74bfUL,
   0x00000009a01158f7UL,
   0x00000001f288d502UL,
   0x0000000af0834285UL,
   0x0000000c936df23fUL,
   0x00000002d38ea826UL,
   0x0000000b1966249aUL,
   0x0000000bc43458d4UL,
   0x000000011eb6a09cUL,
   0x0000000d49d9986cUL,
   0x0000000dd9067c0eUL,
   0x0000000ce383aa71UL,
   0x00000000739c5a2fUL,
   0x0000000770f58eaaUL,
   0x0000000a5d87da4dUL,
   0x0000000401b685acUL,
   0x0000000c65512bc1UL,
   0x00000006999d7387UL,
   0x0000000e23d36997UL,
   0x0000000e30f1d174UL,
   0x000000016e46fc04UL,
   0x0000000200efa090UL,
   0x000000018d86ea94UL,
   0x0000000b75de5761UL,
   0x00000009e50de39dUL,
   0x0000000d7a0a0161UL,
   0x0000000537a63844UL,
   0x0000000e4f4de023UL,
   0x0000000c5b83066fUL,
   0x0000000b9a2f9eb6UL,
   0x000000082a761d43UL,
   0x00000007088ad873UL,
   0x00000005b512f418UL,
   0x0000000a373cf2e4UL,
   0x00000005937d7c89UL,
   0x0000000cca051304UL,
   0x00000007a84e3efbUL,
   0x000000074d80c91bUL,
   0x00000004ad73e91dUL,
   0x0000000490cea84aUL,
   0x000000052e4f1987UL,
   0x0000000ec811379eUL,
   0x0000000b4f570589UL,
   0x00000005a6c46e81UL,
   0x0000000ca857badaUL,
   0x0000000bb9c86860UL,
   0x0000000b2632ee04UL,
   0x00000003f597b324UL,
   0x00000007df14d546UL,
   0x00000005978d3925UL,
   0x000000098498767bUL,
   0x000000015966a839UL,
   0x00000006923743efUL,
   0x000000052f38b460UL,
   0x00000006a2df69edUL,
   0x000000084151f66cUL,
   0x00000001ee304eabUL,
   0x0000000a082ae4afUL,
   0x00000000de4e6afaUL,
   0x00000008131b4166UL,
   0x0000000af5b7967aUL,
   0x000000016d942f84UL,
   0x0000000dab10053eUL,
   0x0000000cce886f54UL,
   0x000000039bc89ef4UL,
   0x0000000a5b7d9067UL,
   0x00000002fb039e23UL,
   0x000000006d82231dUL,
   0x000000003a946dd7UL,
   0x00000008b719555cUL,
   0x00000005352ece13UL,
   0x0000000904fb9151UL,
   0x0000000c7d7cc8d1UL,
   0x0000000d20511b70UL,
   0x0000000f2411eeb8UL,
   0x00000005b4a24ed9UL,
   0x0000000c00fe866fUL,
   0x0000000eb118811aUL,
   0x0000000cabf21b14UL,
   0x0000000052e3a95fUL,
   0x0000000506d306f1UL,
   0x000000022cd662d4UL,
   0x000000089161da55UL,
   0x00000007db947827UL,
   0x0000000b70b47976UL,
   0x0000000814e4e0edUL,
   0x00000008cb8f07f3UL,
   0x0000000b6979fdc4UL,
   0x0000000b0eebb6b0UL,
   0x00000005ec980ef2UL,
   0x00000004b53ccab8UL,
   0x00000009c80770e3UL,
   0x0000000b7ee43a52UL,
   0x0000000a8ef24d04UL,
   0x00000009ec4f67e6UL,
   0x0000000d5f2fb080UL,
   0x0000000efc528d35UL,
   0x0000000db181ccfbUL,
   0x000000039330efd0UL,
   0x00000001a7dd101aUL,
   0x00000004ac3982ecUL,
   0x00000007037e17dcUL,
   0x0000000366188495UL,
   0x000000002458d8a7UL,
   0x00000005f004f923UL,
   0x00000004fe549703UL,
   0x00000004d33fc825UL,
   0x0000000016f29207UL,
   0x0000000a5b2b61a0UL,
   0x0000000d9ea2cb3fUL,
   0x000000009d5e3b9bUL,
   0x00000004e473ff93UL,
   0x000000051e981524UL,
   0x000000068db475adUL,
   0x0000000def9cdca4UL,
   0x000000044a257b51UL,
   0x000000050a9ee66aUL,
   0x00000007b40b799bUL,
   0x00000004111f2de4UL,
   0x0000000cfcfb6b09UL,
   0x0000000f2412713aUL,
   0x00000008d799e9ddUL,
   0x0000000534748e45UL,
   0x000000032f291f51UL,
   0x0000000030363bd3UL,
   0x000000012906d84dUL,
   0x00000006bd9344a9UL,
   0x000000061a5524f1UL,
   0x0000000a94d8e02bUL,
   0x000000082d03a557UL,
   0x0000000468cdf94aUL,
   0x0000000bdd69de40UL,
   0x0000000ea8853fd9UL,
   0x0000000d6caf9343UL,
   0x000000001755e839UL,
   0x0000000badf446deUL,
   0x0000000fe70eae5aUL,
   0x00000001f3817ad1UL,
   0x000000091db0de1aUL,
   0x0000000c1fc0df55UL,
   0x0000000b55de01ccUL,
   0x000000066c5829bdUL,
   0x000000033cb31ff9UL,
   0x0000000ad671f856UL,
   0x0000000534431aefUL,
   0x0000000d30fd939aUL,
   0x0000000826d24c57UL,
   0x0000000d40d5f1b1UL,
   0x000000058f22448cUL,
   0x000000083611d663UL,
   0x0000000f4df3f635UL,
   0x00000001c1071941UL,
   0x00000000f870bccbUL,
   0x000000013a62329eUL,
   0x00000006d6e094a0UL,
   0x000000013c44a6a7UL,
   0x0000000129bc445bUL,
   0x000000059ee90dfdUL,
   0x00000000e0a5171aUL,
   0x00000005f92372baUL,
   0x00000008638592efUL,
   0x000000000d72f3b5UL,
   0x0000000bc7e60a8cUL,
   0x0000000ce5895c63UL,
   0x0000000e41b1ca5dUL,
   0x0000000e615ea62cUL,
   0x00000006993e2180UL,
   0x00000000cc37d82cUL,
   0x000000026af573f3UL,
   0x00000001eb95a424UL,
   0x000000050e5fbc99UL,
   0x0000000fb89b34b2UL,
   0x00000009571a8d0fUL,
   0x00000009d1a63a99UL,
   0x00000009a033e7e7UL,
   0x0000000d77b20f8cUL,
   0x0000000ed2ce19b0UL,
   0x00000005731543c1UL,
   0x0000000a59b97f53UL,
   0x00000001b3503950UL,
   0x00000007cc1f4899UL,
   0x00000003b5a20f14UL,
   0x00000003fb33bf95UL,
   0x000000024850c92fUL,
   0x0000000e3e322563UL,
   0x0000000ba303ab82UL,
   0x00000005a004a3cbUL,
   0x00000001bc3a579dUL,
   0x0000000bc3dd3ba0UL,
   0x0000000df582df03UL,
   0x0000000dfd57af2cUL,
   0x00000003863e1da0UL,
   0x0000000dac52e26fUL,
   0x00000008eb863556UL,
   0x000000094d19e451UL,
   0x00000001d50d8f5fUL,
   0x000000027d1987deUL,
   0x00000000aadc2f1eUL,
   0x0000000d55af6b1dUL,
   0x0000000737fe1509UL,
   0x0000000a49e0fe3bUL,
   0x00000002a49eeaf9UL,
   0x00000000c946b05cUL,
   0x0000000ca43c3583UL,
   0x000000019f868513UL,
   0x000000069cbd7558UL,
   0x00000005043e7034UL,
   0x0000000616e82885UL,
   0x0000000fd919ba26UL,
   0x0000000b50ca391fUL,
   0x0000000c1c578673UL,
   0x0000000d4cb35af7UL,
   0x0000000f82970fb0UL,
   0x00000002fe746c03UL,
   0x00000008a89c5009UL,
   0x00000006228cb500UL,
   0x000000027ea5af6bUL,
   0x0000000dbce2be47UL,
   0x0000000bd304a07cUL,
   0x0000000436d1ffecUL,
   0x0000000e616c764aUL,
   0x0000000e50868951UL,
   0x000000008cb63318UL,
   0x000000006a39fbc8UL,
   0x0000000d42cede82UL,
   0x0000000814c745ceUL,
   0x0000000d9032244bUL,
   0x0000000e20bc0e5aUL,
   0x00000002ce95450bUL,
   0x000000015cae0ea8UL,
   0x00000004a2ff168fUL,
   0x00000003c6b4fe2fUL,
   0x00000001999a6d47UL,
   0x0000000df7755c04UL,
   0x00000000e2da75e1UL,
   0x0000000cfb8748c2UL,
   0x00000006472c5913UL,
   0x0000000ca51e4ce0UL,
   0x000000034f2ca384UL,
   0x00000007b305ce7cUL,
   0x0000000f3704894aUL,
   0x000000055945c075UL,
   0x0000000104252729UL,
   0x0000000b16e409ffUL,
   0x00000003676f5fc8UL,
   0x00000008b9ba144fUL,
   0x0000000a322964e9UL,
   0x000000009841268bUL,
   0x00000008c8912053UL,
   0x0000000db2e4f8d1UL,
   0x000000062a58cbf4UL,
   0x000000034a15524cUL,
   0x00000000e73ea403UL,
   0x000000038492c5dcUL,
   0x0000000865ab5b6dUL,
   0x0000000b638c0fbdUL,
   0x000000085ce2ca0eUL,
   0x0000000e45949e30UL,
   0x00000000431f7881UL,
   0x00000004f8626706UL,
   0x0000000f59c896ceUL,
   0x00000008d4e37dd7UL,
   0x000000072e5e016bUL,
   0x000000019c9570a6UL,
   0x0000000eb0e55828UL,
   0x0000000f3cb02a1bUL,
   0x0000000b609ff814UL,
   0x0000000dab87f876UL,
   0x000000076d547356UL,
   0x0000000b9f95ae4eUL,
   0x000000063a65e9e3UL,
   0x0000000b6838a991UL,
   0x000000012b64eb81UL,
   0x0000000c59ced5a6UL,
   0x0000000d715aecdbUL,
   0x0000000b4291fe13UL,
   0x000000006d0d0693UL,
   0x0000000f98794c86UL,
   0x00000005c816d4d8UL,
   0x0000000c947590ffUL,
   0x000000080bb44a94UL,
   0x0000000f59bd80c8UL,
   0x0000000df761d2bcUL,
   0x0000000217a8fb51UL,
   0x000000093d47240dUL,
   0x0000000761920193UL,
   0x0000000e4e5eba29UL,
   0x0000000eeca76549UL,
   0x0000000a1bbfc9c4UL,
   0x0000000c711b2477UL,
   0x0000000325b5a666UL,
   0x0000000ce05f41f2UL,
   0x00000003da9c4cffUL,
   0x0000000120c47b51UL,
   0x0000000cd32263aeUL,
   0x0000000e799e7548UL,
   0x0000000ae372d335UL,
   0x0000000063ddbda3UL,
   0x0000000267fac28cUL,
   0x000000001fc9d86bUL,
   0x000000017641543bUL,
   0x0000000c72e347daUL,
   0x00000006ffd0717aUL,
   0x00000003c30cb70fUL,
   0x00000000820ea2bdUL,
   0x00000003e9d4bf2bUL,
   0x0000000a3c30b85cUL,
   0x0000000f9f0118dfUL,
   0x0000000e4b9fe4d3UL,
   0x000000029c0611aeUL,
   0x0000000a8c35fa15UL,
   0x00000001b9e934caUL,
   0x0000000480cb9d1bUL,
   0x0000000bf800f039UL,
   0x0000000c84dca5d6UL,
   0x00000007bc72f527UL,
   0x00000007b9239faeUL,
   0x00000007d89ef157UL,
   0x00000007ac85a437UL,
   0x0000000d16f6d1beUL,
   0x0000000edf98b6ffUL,
   0x0000000e8686dc27UL,
   0x00000004859dce4bUL,
   0x0000000041627612UL,
   0x0000000fc09cbd90UL,
   0x0000000fdae828b9UL,
   0x00000008e8ab9aacUL,
   0x0000000e3c3a5acbUL,
   0x0000000df138b3f6UL,
   0x000000068b6499ceUL,
   0x0000000bf229a907UL,
   0x0000000c5565d691UL,
   0x00000008f8119c05UL,
   0x000000096751f8e6UL,
   0x0000000ac2f319d4UL,
   0x0000000dc9a8a43bUL,
   0x000000023e877e11UL,
   0x00000006bd59226fUL,
   0x000000059360ec26UL,
   0x0000000e9afc1dd5UL,
   0x0000000de69624a6UL,
   0x0000000de54a22a7UL,
   0x0000000ea27ba143UL,
   0x00000008bcdef6a3UL,
   0x00000004779f40beUL,
   0x000000065a1a6cbcUL,
   0x0000000f31b71b67UL,
   0x00000001dee9ec9bUL,
   0x0000000a8bbd546bUL,
   0x00000004d77af897UL,
   0x000000053be52417UL,
   0x00000009ab39f2e2UL,
   0x0000000c7672be23UL,
   0x000000085bb59414UL,
   0x0000000f77b6f781UL,
   0x0000000aecf29f03UL,
   0x00000003ea7deeb5UL,
   0x000000053154616bUL,
   0x0000000f0ad4172eUL,
   0x0000000ac97900c4UL,
   0x000000024af96431UL,
   0x0000000742dcac09UL,
   0x0000000b77612a7cUL,
   0x000000043f8e0b06UL,
   0x0000000b9af4d04cUL,
   0x00000005f0c0eeb7UL,
   0x0000000beed5d839UL,
   0x0000000594bc055fUL,
   0x0000000bf3d4ee51UL,
   0x000000036dc329e7UL,
   0x00000006292a913dUL,
   0x0000000853afc28dUL,
   0x00000008f669cd4dUL,
   0x000000035d67967dUL,
   0x0000000a1ba1cda9UL,
   0x0000000475e70d85UL,
   0x0000000db124355eUL,
   0x0000000b7464de4bUL,
   0x0000000210a5d6ecUL,
   0x00000003f3b26a00UL,
   0x00000003b654ab0bUL,
   0x00000005461eabb8UL,
   0x0000000add3bc40fUL,
   0x00000000223eae50UL,
   0x0000000d0a8f290dUL,
   0x000000070ec2982dUL,
   0x00000000e98ba15aUL,
   0x00000001bf087c2eUL,
   0x00000006e98233f2UL,
   0x0000000b06e2c22bUL,
   0x000000045483b62dUL,
   0x00000002fadab9aeUL,
   0x0000000112d8a187UL,
   0x0000000c1a9043c6UL,
   0x000000007abad130UL,
   0x000000092fd1710eUL,
   0x0000000f55801505UL,
   0x0000000f42daa0b3UL,
   0x000000063e7b4d45UL,
   0x0000000f976ab37bUL,
   0x000000059c9833d0UL,
   0x000000098cbdb021UL,
   0x0000000da67a27caUL,
   0x0000000d0e6edf39UL,
   0x0000000d8fdd70b9UL,
   0x00000006b86d3b06UL,
   0x00000003979ed2b7UL,
   0x000000046a8a0a6cUL,
   0x0000000fba0b5f5fUL,
   0x0000000c34a9713dUL,
   0x0000000840e7387cUL,
   0x0000000ca04d9f6aUL,
   0x000000076073e651UL,
   0x0000000e6f2fca96UL,
   0x0000000daef51fa4UL,
   0x00000007824e6073UL,
   0x0000000dbbb9e428UL,
   0x000000064bda5a5dUL,
   0x0000000d3944a8beUL,
   0x0000000895b7c247UL,
   0x0000000a8a092b5eUL,
   0x00000008454ae0f6UL,
   0x00000001a3109cc6UL,
   0x0000000411731a19UL,
   0x0000000ee3ccd9e5UL,
   0x0000000865688814UL,
   0x000000084c59bdd7UL,
   0x0000000bdf4f34e2UL,
   0x0000000192b2633cUL,
   0x0000000f7c30ff94UL,
   0x0000000bbd0187c5UL,
   0x000000036858be42UL,
   0x00000007cf38933fUL,
   0x0000000b1c48417eUL,
   0x000000077b63288cUL,
   0x0000000794af1c0eUL,
   0x0000000b5afd4a02UL,
   0x000000092e67eb6bUL,
   0x00000006253569e5UL,
   0x00000001405ca65fUL,
   0x00000004ca61bba3UL,
   0x000000006fe876e9UL,
   0x0000000c25b98680UL,
   0x00000000bd52f241UL,
   0x0000000de92bdbc6UL,
   0x00000007114244f7UL,
   0x0000000c92109927UL,
   0x000000011246d25fUL,
   0x0000000878963531UL,
   0x0000000b8f639289UL,
   0x0000000edd1ee2dcUL,
   0x00000002dd27bd83UL,
   0x00000005b77fb633UL,
   0x000000092d244feaUL,
   0x0000000ff29f378bUL,
   0x0000000cd74b01dfUL,
   0x0000000caee75d99UL,
   0x000000032a7950e7UL,
   0x00000008ab7143d0UL,
   0x00000004a396d396UL,
   0x000000027cc982aaUL,
   0x0000000748ffbcacUL,
   0x00000007dc1212dbUL,
   0x000000060491f30fUL,
   0x00000006462a44c5UL,
   0x0000000f693b3934UL,
   0x00000002c85c32c8UL,
   0x000000058842e73aUL,
   0x000000039c5c936aUL,
   0x000000059da18b06UL,
   0x0000000b0c4be569UL,
   0x0000000b38429749UL,
   0x000000014d177c42UL,
   0x0000000b2890755cUL,
   0x0000000c316f3c01UL,
   0x000000097a978118UL,
   0x00000006e3af9c97UL,
   0x0000000b16bfcf5bUL,
   0x0000000fbdedeaa1UL,
   0x000000062d2efff3UL,
   0x0000000221e13b03UL,
   0x00000006f189a8f4UL,
   0x0000000ba3c855cfUL,
   0x00000004d9b593f1UL,
   0x000000070bdb83c4UL,
   0x00000007be402a75UL,
   0x0000000acbb1dcf6UL,
   0x00000006d76dd708UL,
   0x00000004210a8723UL,
   0x0000000e4a9e3182UL,
   0x00000000b86ea177UL,
   0x0000000589c7c8dfUL,
   0x0000000728f649ccUL,
   0x0000000235daf936UL,
   0x0000000ed5b13b07UL,
   0x00000009838cc62bUL,
   0x0000000699ea0fb3UL,
   0x0000000533af329dUL,
   0x00000000486ec47dUL,
   0x0000000ea7e7874dUL,
   0x0000000ae99ea9c5UL,
   0x000000037e02d2d5UL,
   0x0000000b92cf5ea1UL,
   0x0000000e8c6fa527UL,
   0x000000093ac59f00UL,
   0x0000000a5876d0fbUL,
   0x000000042664d4abUL,
   0x0000000672c67c2fUL,
   0x0000000a499d1a9bUL,
   0x00000001c55c99a8UL,
   0x00000005d5644f76UL,
   0x0000000149b6cd96UL,
   0x00000005d19a752aUL,
   0x0000000fa5fce591UL,
   0x00000005380ec50cUL,
   0x0000000dea0d752dUL,
   0x00000001faf5309bUL,
   0x0000000e3b7a775eUL,
   0x0000000173d59edbUL,
   0x0000000b8e38cca5UL,
   0x00000001e43cad4eUL,
   0x000000027dedf623UL,
   0x0000000da72d480fUL,
   0x000000099434d76fUL,
   0x00000008e06320e5UL,
   0x000000012cc5d9b3UL,
   0x0000000d4ec00d0aUL,
   0x00000008fa256ec8UL,
   0x00000002a7755b41UL,
   0x0000000649598f17UL,
   0x0000000048a9ea61UL,
   0x0000000b749bbe4dUL,
   0x000000059e4c9da2UL,
   0x000000050395f36cUL,
   0x00000006b07149d2UL,
   0x00000004f9406d7fUL,
   0x000000092febe987UL,
   0x0000000d7bf93ed2UL,
   0x00000001e66cc0f3UL,
   0x00000006c48e37c0UL,
   0x00000003ad8159d5UL,
   0x000000048f41fbc8UL,
   0x0000000cd5f40d31UL,
   0x00000004d9d50e50UL,
   0x0000000377552d44UL,
   0x0000000d6400b5bfUL,
   0x0000000205260a56UL,
   0x0000000c319eaf12UL,
   0x0000000bb3016818UL,
   0x0000000194c9caa5UL,
   0x00000003205df053UL,
   0x00000008dbf64dc8UL,
   0x00000005cc34b609UL,
   0x00000007d2367f18UL,
   0x000000020d6cee2eUL,
   0x0000000c9f86c18eUL,
   0x0000000e2b1f4620UL,
   0x000000009c52f03eUL,
   0x000000007d8b9b31UL,
   0x00000002b85f049fUL,
   0x0000000e0b542614UL,
   0x0000000d0f06b745UL,
   0x0000000df7b0f962UL,
   0x0000000d7b41890fUL,
   0x000000024baf7927UL,
   0x0000000cc63c5347UL,
   0x0000000c9dbe3e8eUL,
   0x000000052b1c7225UL,
   0x000000073f558c8dUL,
   0x0000000542702b85UL,
   0x0000000578f18fddUL,
   0x0000000a76cf36efUL,
   0x0000000a3cb92407UL,
   0x0000000b7ad6cd05UL,
   0x00000006d0f34533UL,
   0x0000000416083d1bUL,
   0x00000002bdb7fab0UL,
   0x000000029619e1d2UL,
   0x0000000fe824f4c1UL,
   0x00000007a5ff22b9UL,
   0x00000005be7f7ce2UL,
   0x00000004140ddebeUL,
   0x0000000ec104f338UL,
   0x00000003c6ea6417UL,
   0x00000004c68c4841UL,
   0x0000000738550624UL,
   0x000000095d52ffbeUL,
   0x00000001211a3407UL,
   0x000000085c2667c7UL,
   0x0000000d3fcfc70aUL,
   0x000000062c79fa03UL,
   0x0000000e5a01d1deUL,
   0x000000021a6f78c0UL,
   0x000000067a9d08d0UL,
   0x00000003521d86a9UL,
   0x0000000821858962UL,
   0x00000000238c9ab4UL,
   0x0000000d377e444eUL,
   0x00000009b4db4370UL,
   0x0000000326d40d28UL,
   0x0000000cca399d64UL,
   0x000000029e717061UL,
   0x000000081c257536UL,
   0x0000000b5398ff6fUL,
   0x00000006246d505dUL,
   0x000000052de44206UL,
   0x0000000d4bfe70a7UL,
   0x00000001256f3bbfUL,
   0x0000000e18dca845UL,
   0x0000000cadc6270eUL,
   0x0000000ceecebcf9UL,
   0x000000030490b131UL,
   0x00000003499eae73UL,
   0x0000000e407687b5UL,
   0x00000000d16a1b5cUL,
   0x00000000aed4fc7cUL,
   0x0000000977235aceUL,
   0x0000000e45bc089cUL,
   0x0000000d1c7e8b0fUL,
   0x0000000c801f2a62UL,
   0x00000009bb982febUL,
   0x0000000c2ade21d5UL,
   0x0000000e664c4cdcUL,
   0x0000000b5b1b7d8dUL,
   0x000000057e319e42UL,
   0x0000000a62708260UL,
   0x00000004d49e8e90UL,
   0x00000000cb5f349aUL,
   0x000000097f8c8487UL,
   0x0000000bf26ecbd1UL,
   0x00000006a22fc93fUL,
   0x0000000f40123ad5UL,
   0x0000000f2864b84fUL,
   0x000000052b894393UL,
   0x0000000aeac3e443UL,
   0x000000064a6e37e9UL,
   0x00000005ff905511UL,
   0x00000000f9368ae9UL,
   0x0000000304c961d1UL,
   0x0000000901e3d5efUL,
   0x00000003d9c9e1eaUL,
   0x000000014af08310UL,
   0x0000000f7d5f48faUL,
   0x00000004cc90c712UL,
   0x000000093eb3c4f2UL,
   0x0000000c64af2ee0UL,
   0x0000000ee9b0b880UL,
   0x000000059e9f00c4UL,
   0x0000000f0e385a56UL,
   0x0000000013e3176aUL,
   0x000000022cefe2bfUL,
   0x0000000e8d646da2UL,
   0x0000000fa07e9914UL,
   0x000000064a342dc3UL,
   0x0000000029436fdeUL,
   0x00000003f436a788UL,
   0x0000000ebce59d33UL,
   0x0000000d1cc417e5UL,
   0x0000000bdabb3afcUL,
   0x00000002b075aa91UL,
   0x0000000cf479bc86UL,
   0x00000001bc69c922UL,
   0x0000000f70bed102UL,
   0x000000073fba7412UL,
   0x0000000dad289c99UL,
   0x000000025fa19a7eUL,
   0x0000000a5a248105UL,
   0x000000059c85904fUL,
   0x0000000587368f7aUL,
   0x00000006ddf6cd9bUL,
   0x0000000276aaeac2UL,
   0x000000039793390eUL,
   0x0000000ee79121bdUL,
   0x000000043b22f813UL,
   0x0000000137d42357UL,
   0x000000067857c8bdUL,
   0x000000046cf4e741UL,
   0x00000001d18cd171UL,
   0x0000000a9806c31fUL,
   0x000000006605176cUL,
   0x00000000f592c1acUL,
   0x00000007265a10a4UL,
   0x0000000e89d3f153UL,
   0x0000000b2c1d25d5UL,
   0x0000000fc221a68cUL,
   0x000000021bc5cb0fUL,
   0x00000007d8865a48UL,
   0x000000014fb6a9c1UL,
   0x0000000826702ff5UL,
   0x0000000c875eecddUL,
   0x0000000334906e55UL,
   0x0000000e75f38920UL,
   0x0000000e68cc8585UL,
   0x0000000e21989dadUL,
   0x0000000991c0a54fUL,
   0x0000000afc2e4db2UL,
   0x000000049215ae09UL,
   0x00000004414dd21cUL,
   0x0000000270102c2bUL,
   0x0000000d74d46724UL,
   0x0000000d8ba0e6cfUL,
   0x00000004924c591cUL,
   0x000000014a218727UL,
   0x0000000ec649a317UL,
   0x000000040506e864UL,
   0x00000004a5fce324UL,
   0x0000000432da3920UL,
   0x0000000be6c87867UL,
   0x000000096d47ab50UL,
   0x000000013b26554aUL,
   0x000000042d294c1aUL,
   0x000000043a8f4537UL,
   0x0000000ec9981703UL,
   0x00000009d23e9feaUL,
   0x0000000a5e63c741UL,
   0x0000000b590555a7UL,
   0x0000000af5cc76d0UL,
   0x000000036f6807beUL,
   0x0000000d9e7509baUL,
   0x000000008e7485e6UL,
   0x0000000ca410c173UL,
   0x000000034c0efac9UL,
   0x0000000aa8dd95f8UL,
   0x000000092ff8e340UL,
   0x00000002fcf617e5UL,
   0x0000000f4ee3deeaUL,
   0x0000000ec3675f06UL,
   0x000000011d3034ccUL,
   0x000000053d80da67UL,
   0x00000002ffd3e2edUL,
   0x0000000701c5dbcaUL,
   0x0000000fd41bd301UL,
   0x0000000176d0d999UL,
   0x000000084a7a607aUL,
   0x00000003a4cd4f6eUL,
   0x000000029fd854f3UL,
   0x0000000239143be4UL,
   0x0000000c1d83b7ceUL,
   0x00000003998e35f9UL,
   0x0000000c9cade2feUL,
   0x000000067a7ce5f8UL,
   0x000000058096eb5eUL,
   0x0000000129003b1aUL,
   0x000000058cd60dd3UL,
   0x00000007ec9c978cUL,
   0x00000008209b7fc6UL,
   0x0000000b1a07b065UL,
   0x00000002f8c5d980UL,
   0x0000000ec68f5262UL,
   0x00000009f6738ae8UL,
   0x0000000e240da32dUL,
   0x000000029a692dd3UL,
   0x000000093a2fc212UL,
   0x000000090a7ad415UL,
   0x000000038462d719UL,
   0x000000088d09ed64UL,
   0x0000000629414143UL,
   0x0000000f37f54627UL,
   0x0000000f654223daUL,
   0x00000009866d0462UL,
   0x000000039b7e344bUL,
   0x0000000e29b0d31eUL,
   0x00000004d26f996bUL,
   0x0000000ca999e2d4UL,
   0x000000048244cecaUL,
   0x0000000db430a091UL,
   0x0000000b20a09f71UL,
   0x000000089d7a977dUL,
   0x0000000d0c7d781fUL,
   0x000000045dbd608bUL,
   0x00000005f0eaf573UL,
   0x00000004b72a881eUL,
   0x00000006721d71acUL,
   0x0000000aea5b5257UL,
   0x0000000729da786eUL,
   0x0000000b7bbb055eUL,
   0x000000033c26e035UL,
   0x0000000bbb1faaf3UL,
   0x0000000a7acc30bcUL,
   0x00000001ce0841a4UL,
   0x0000000244d1d408UL,
   0x0000000cde684816UL,
   0x00000000f8fb4cdaUL,
   0x0000000706c97e43UL,
   0x0000000c971d3afbUL,
   0x0000000fda0d9c09UL,
   0x0000000016b86da3UL,
   0x0000000fad3fd2e5UL,
   0x0000000bac1633c9UL,
   0x00000002309feea7UL,
   0x00000000033737bbUL,
   0x00000009aed89097UL,
   0x000000068538abb5UL,
   0x0000000828f7850dUL,
   0x000000072432d95dUL,
   0x0000000261a8e5a9UL,
   0x0000000a200eb1b2UL,
   0x0000000c3de7f043UL,
   0x0000000bf74c5970UL,
   0x00000006dd1481b8UL,
   0x0000000aa94bbef6UL,
   0x0000000da7e65697UL,
   0x0000000bc3ab5693UL,
   0x0000000fac70dbecUL,
   0x000000011c7b546dUL,
   0x0000000f2f1877aeUL,
   0x0000000ddfd559cbUL,
   0x0000000213843237UL,
   0x0000000d35629a71UL,
   0x000000066b966ff8UL,
   0x0000000f7c3d2b42UL,
   0x0000000d2a9bf013UL,
   0x000000082aade491UL,
   0x000000080a74d66aUL,
   0x0000000c23180cd5UL,
   0x000000013bc699afUL,
   0x0000000568f373afUL,
   0x00000004e8f6cb22UL,
   0x00000000236593daUL,
   0x0000000c06d419daUL,
   0x0000000fb63c9338UL,
   0x0000000c58ea0e62UL,
   0x00000003f129af28UL,
   0x00000001bc5d8e7cUL,
   0x00000005a0cce5a2UL,
   0x000000012138fcc9UL,
   0x00000006475b47b3UL,
   0x000000036127061cUL,
   0x0000000a66ea1c90UL,
   0x0000000c7622d06fUL,
   0x00000007b06f9883UL,
   0x000000017f9dd0f5UL,
   0x00000004f7d20a59UL,
   0x000000080ca1778dUL,
   0x000000034bf99f09UL,
   0x0000000b1f6b20ffUL,
   0x0000000ddc248171UL,
   0x000000079adedf2dUL,
   0x0000000e7b8ec414UL,
   0x00000001660b1a2aUL,
   0x0000000596131143UL,
   0x0000000ed5876f22UL,
   0x0000000ccf196212UL,
   0x00000005a7da3ed3UL,
   0x00000005d7c1c564UL,
   0x0000000ebf3b80d4UL,
   0x00000000fbb5da08UL,
   0x0000000751b26b7fUL,
   0x0000000f646e15e0UL,
   0x000000048cf268f5UL,
   0x0000000681ff913eUL,
   0x00000008a60709eeUL,
   0x0000000ee8aa3c19UL,
   0x0000000d74c7190bUL,
   0x0000000403a516f6UL,
   0x000000043859f5e7UL,
   0x0000000674b05601UL,
   0x000000029dc78f7bUL,
   0x0000000f871a0d9cUL,
   0x0000000149cd7e80UL,
   0x0000000e0ebb3dadUL,
   0x0000000cfd60dc21UL,
   0x0000000fcac192f3UL,
   0x0000000da0bb9f49UL,
   0x0000000377891815UL,
   0x00000008cf831888UL,
   0x0000000d8ad9cff2UL,
   0x000000066ef37c63UL,
   0x0000000289532c5dUL,
   0x000000045d8a5400UL,
   0x0000000452111b4dUL,
   0x0000000be9b62af0UL,
   0x00000004a7fa60afUL,
   0x0000000f38ab400eUL,
   0x0000000329b05789UL,
   0x00000005edba3023UL,
   0x00000005f48632e5UL,
   0x0000000c44562244UL,
   0x0000000781f865e7UL,
   0x00000004868de42dUL,
   0x0000000b7d2aafddUL,
   0x00000000652863c6UL,
   0x00000009c8c0a919UL,
   0x0000000a566fd21eUL,
   0x0000000d42a60c7aUL,
   0x00000003b2fa8afeUL,
   0x00000004feead808UL,
   0x00000004e08205a5UL,
   0x00000002ca3d8a2fUL,
   0x0000000983fc5a57UL,
   0x0000000c23db45c9UL,
   0x0000000a37e0ba04UL,
   0x00000005f510ba05UL,
   0x00000001601a2ff1UL,
   0x000000030cccbfe0UL,
   0x00000003880f5176UL,
   0x00000000ea5aee4fUL,
   0x0000000b1b166fdbUL,
   0x00000007b3ca3761UL,
   0x000000064fae3ebfUL,
   0x0000000447b9e7acUL,
   0x0000000d9f564f30UL,
};
apriltag_family_t *tag36h10_create()
{
   apriltag_family_t *tf = calloc(1, sizeof(apriltag_family_t));
   tf->name = strdup("tag36h10");
   tf->h = 10;
   tf->ncodes = 2320;
   tf->codes = codedata;
   tf->nbits = 36;
   tf->bit_x = calloc(36, sizeof(uint32_t));
   tf->bit_y = calloc(36, sizeof(uint32_t));
   tf->bit_x[0] = 1;
   tf->bit_y[0] = 1;
   tf->bit_x[1] = 2;
   tf->bit_y[1] = 1;
   tf->bit_x[2] = 3;
   tf->bit_y[2] = 1;
   tf->bit_x[3] = 4;
   tf->bit_y[3] = 1;
   tf->bit_x[4] = 5;
   tf->bit_y[4] = 1;
   tf->bit_x[5] = 2;
   tf->bit_y[5] = 2;
   tf->bit_x[6] = 3;
   tf->bit_y[6] = 2;
   tf->bit_x[7] = 4;
   tf->bit_y[7] = 2;
   tf->bit_x[8] = 3;
   tf->bit_y[8] = 3;
   tf->bit_x[9] = 6;
   tf->bit_y[9] = 1;
   tf->bit_x[10] = 6;
   tf->bit_y[10] = 2;
   tf->bit_x[11] = 6;
   tf->bit_y[11] = 3;
   tf->bit_x[12] = 6;
   tf->bit_y[12] = 4;
   tf->bit_x[13] = 6;
   tf->bit_y[13] = 5;
   tf->bit_x[14] = 5;
   tf->bit_y[14] = 2;
   tf->bit_x[15] = 5;
   tf->bit_y[15] = 3;
   tf->bit_x[16] = 5;
   tf->bit_y[16] = 4;
   tf->bit_x[17] = 4;
   tf->bit_y[17] = 3;
   tf->bit_x[18] = 6;
   tf->bit_y[18] = 6;
   tf->bit_x[19] = 5;
   tf->bit_y[19] = 6;
   tf->bit_x[20] = 4;
   tf->bit_y[20] = 6;
   tf->bit_x[21] = 3;
   tf->bit_y[21] = 6;
   tf->bit_x[22] = 2;
   tf->bit_y[22] = 6;
   tf->bit_x[23] = 5;
   tf->bit_y[23] = 5;
   tf->bit_x[24] = 4;
   tf->bit_y[24] = 5;
   tf->bit_x[25] = 3;
   tf->bit_y[25] = 5;
   tf->bit_x[26] = 4;
   tf->bit_y[26] = 4;
   tf->bit_x[27] = 1;
   tf->bit_y[27] = 6;
   tf->bit_x[28] = 1;
   tf->bit_y[28] = 5;
   tf->bit_x[29] = 1;
   tf->bit_y[29] = 4;
   tf->bit_x[30] = 1;
   tf->bit_y[30] = 3;
   tf->bit_x[31] = 1;
   tf->bit_y[31] = 2;
   tf->bit_x[32] = 2;
   tf->bit_y[32] = 5;
   tf->bit_x[33] = 2;
   tf->bit_y[33] = 4;
   tf->bit_x[34] = 2;
   tf->bit_y[34] = 3;
   tf->bit_x[35] = 3;
   tf->bit_y[35] = 4;
   tf->width_at_border = 8;
   tf->total_width = 10;
   tf->reversed_border = false;
   return tf;
}

void tag36h10_destroy(apriltag_family_t *tf)
{
   free(tf->bit_x);
   free(tf->bit_y);
   free(tf->name);
   free(tf);
}
